:py:mod:`holisticai.security.metrics`
=====================================

.. automodule:: holisticai.security.metrics
    :no-members:
    :no-inherited-members:


.. autosummary::
    :nosignatures:
    :template: function.rst
    :toctree: .generated/

    k_anonymity
    l_diversity
    shapr_score
    data_minimization_score
    attribute_attack_score
